'use strict';

var ricosTypes = require('ricos-types');
var wixRichContentEditorCommon = require('wix-rich-content-editor-common');
var wixRichContentPluginCommons = require('wix-rich-content-plugin-commons');
var consts = require('./consts.js');
var toolbar_imagePluginService = require('./toolbar/imagePluginService.js');
var types = require('./types.js');
var icons_InsertPluginIcon = require('./icons/InsertPluginIcon.js');
require('ricos-schema');
require('lodash');
require('react');

const imagePluginService = new toolbar_imagePluginService.ImagePluginService();
const handleExternalFileChange = (editorCommands, updateService) => ({ data }) => {
  if (data instanceof Array) {
    data.forEach((file, index) => {
      setTimeout(() => {
        const nodeId = editorCommands.insertBlockWithBlankLines(types.IMAGE_TYPE, consts.RICOS_DEFAULTS, {
          updateSelection: data.length === index + 1
        });
        updateService.updatePluginData({ data: file }, nodeId, types.IMAGE_TYPE, imagePluginService);
      });
    });
  } else {
    const nodeId = editorCommands.insertBlockWithBlankLines(types.IMAGE_TYPE, consts.RICOS_DEFAULTS);
    updateService.updatePluginData({ data }, nodeId, types.IMAGE_TYPE, imagePluginService);
  }
};
const handleNativeFileChange = (editorCommands, uploadService, uploader) => (files) => {
  files.forEach((file, index) => {
    setTimeout(() => {
      const nodeId = editorCommands.insertBlockWithBlankLines(types.IMAGE_TYPE, consts.RICOS_DEFAULTS, {
        updateSelection: files.length === index + 1
      });
      uploadService.uploadFile(
        new File([file], file.name, { type: file.type }),
        nodeId,
        uploader,
        types.IMAGE_TYPE,
        imagePluginService
      );
    });
  });
};
const imageAddToolbars = [
  wixRichContentEditorCommon.TOOLBARS.MOBILE,
  wixRichContentEditorCommon.TOOLBARS.FOOTER,
  wixRichContentEditorCommon.TOOLBARS.SIDE
];
const getAddButtons = (config, services) => {
  return [
    {
      id: ricosTypes.Node_Type.IMAGE,
      label: wixRichContentEditorCommon.INSERT_PLUGIN_BUTTONS.IMAGE,
      dataHook: wixRichContentEditorCommon.INSERT_PLUGIN_BUTTONS.IMAGE,
      icon: icons_InsertPluginIcon,
      tooltip: "ImagePlugin_InsertButton_Tooltip",
      toolbars: imageAddToolbars,
      command: ({ editorCommands }) => {
        const { uploadService, updateService } = services;
        if (config.handleFileSelection) {
          config.handleFileSelection(
            void 0,
            !!config.multi,
            handleExternalFileChange(editorCommands, updateService),
            void 0,
            consts.RICOS_DEFAULTS
          );
        } else {
          const { accept = "image/*", multi = true, handleFileUpload } = config;
          uploadService == null ? void 0 : uploadService.selectFiles(
            accept,
            multi,
            handleNativeFileChange(editorCommands, uploadService, new wixRichContentPluginCommons.Uploader(handleFileUpload))
          );
        }
        return true;
      },
      menuConfig: {
        tags: "Image_plugin_search_tags"
      }
    }
  ];
};

exports.getAddButtons = getAddButtons;
exports.imageAddToolbars = imageAddToolbars;
//# sourceMappingURL=getAddButtons.js.map
