'use strict';

var React = require('react');
var wixRichContentEditorCommon = require('wix-rich-content-editor-common');
var wixRichContentPluginCommons = require('wix-rich-content-plugin-commons');
var wixRichContentToolbarsUi = require('wix-rich-content-toolbars-ui');
var consts = require('./consts.js');
var imageEditorModal_imageEditorModal = require('./image-editor-modal/image-editor-modal.js');
var settings_settings = require('./settings/settings.js');
var toolbar_ImageEditorButton = require('./toolbar/ImageEditorButton.js');
var toolbar_imagePluginService = require('./toolbar/imagePluginService.js');
var types = require('./types.js');
require('ricos-schema');
require('ricos-context');
require('./imageStudio/image-editor-logic.js');
require('./imageStudio/image-studio-opener-loader.js');
require('@wix/design-system');
require('wix-rich-content-ui-components');
require('./dataHooks.js');
require('./settings/use-spoiler-plugin.js');
require('ricos-content');
require('lodash');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefaultCompat(React);

const imagePluginService = new toolbar_imagePluginService.ImagePluginService();
const getToolbarButtons = (config, services) => {
  const {
    modals,
    uploadService,
    updateService,
    context: { isMobile }
  } = services;
  return [
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SIZE,
      modal: {
        Component: wixRichContentEditorCommon.decorateComponentWithProps(wixRichContentToolbarsUi.SizePanel, {
          options: [
            "SMALL",
            "CONTENT",
            "FULL_WIDTH",
            "ORIGINAL"
          ]
        }),
        id: consts.IMAGE_BUTTONS.size
      },
      renderer: (toolbarItem) => /* @__PURE__ */ React__default.default.createElement(wixRichContentToolbarsUi.NodeSizeButton, { id: consts.IMAGE_BUTTONS.size, toolbarItem })
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR,
      attributes: {
        visible: wixRichContentPluginCommons.getVisibleOnlyOnDesktopResolver(isMobile)
      }
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.ALIGNMENT,
      modal: {
        Component: wixRichContentToolbarsUi.AlignmentPanel,
        id: consts.IMAGE_BUTTONS.alignment
      },
      renderer: (toolbarItem) => /* @__PURE__ */ React__default.default.createElement(wixRichContentToolbarsUi.NodeAlignmentButton, { toolbarItem, id: consts.IMAGE_BUTTONS.alignment })
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR,
      attributes: {
        visible: wixRichContentPluginCommons.getVisibleOnlyOnDesktopResolver(isMobile)
      }
    },
    {
      id: consts.imageModals.imageEditor,
      modal: {
        Component: wixRichContentEditorCommon.decorateComponentWithProps(imageEditorModal_imageEditorModal, {
          imagePluginService,
          imageEditorWixSettings: config.imageEditorWixSettings,
          onImageEditorOpen: config.onImageEditorOpen
        }),
        id: consts.imageModals.imageEditor
      },
      dataHook: "imageToolbarButton_image_editor",
      command: ({ src, attributes: { selectedNode } }) => {
        modals == null ? void 0 : modals.openModal(consts.imageModals.imageEditor, {
          componentProps: {
            nodeId: selectedNode.attrs.id,
            src,
            handleFileUpload: config.handleFileUpload
          },
          positioning: { placement: "top" },
          layout: "fullscreen"
        });
      },
      renderer: (toolbarItem) => /* @__PURE__ */ React__default.default.createElement(toolbar_ImageEditorButton, { toolbarItem }),
      attributes: {
        visible: getIsEditImageVisibleResolver(config, isMobile),
        selectedNode: wixRichContentPluginCommons.selectedNodeResolver
      }
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR,
      attributes: {
        visible: getIsEditImageVisibleResolver(config, isMobile)
      }
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.LINK
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SETTINGS,
      modal: {
        Component: settings_settings.Settings,
        id: consts.imageModals.settings
      },
      command: ({ isMobile: isMobile2, attributes: { selectedNode } }) => {
        modals == null ? void 0 : modals.openModal(consts.imageModals.settings, {
          componentProps: {
            nodeId: selectedNode.attrs.id,
            config
          },
          positioning: { placement: "right" },
          layout: isMobile2 ? "fullscreen" : "drawer"
        });
      }
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.REPLACE,
      tooltip: "ReplaceImageButton_Tooltip",
      command: ({ attributes: { selectedNode } }) => {
        if (config.handleFileSelection) {
          config.handleFileSelection(
            void 0,
            false,
            ({ data }) => {
              const file = Array.isArray(data) ? data[0] : data;
              updateService.updatePluginData(
                { data: file },
                selectedNode.attrs.id,
                types.IMAGE_TYPE,
                imagePluginService
              );
            },
            void 0,
            {}
          );
        } else {
          const { accept = "image/*", handleFileUpload } = config;
          uploadService.selectFiles(
            accept,
            false,
            (files) => uploadService.uploadFile(
              files[0],
              selectedNode.attrs.id,
              new wixRichContentPluginCommons.Uploader(handleFileUpload),
              types.IMAGE_TYPE,
              imagePluginService
            )
          );
        }
      }
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR
    },
    {
      id: wixRichContentEditorCommon.PLUGIN_TOOLBAR_BUTTON_ID.DELETE
    }
  ];
};
const getIsEditImageVisibleResolver = (config, isMobile) => ({
  id: "IS_IMAGE_EDIT_BUTTON_VISIBLE",
  resolve: () => !!config.imageEditorWixSettings && !isMobile
});

exports.getToolbarButtons = getToolbarButtons;
//# sourceMappingURL=getToolbarButtons.js.map
