'use strict';

var unidriver = require('@wix/design-system/dist/testkit/unidriver');
var wixRichContentCommon = require('wix-rich-content-common');
var wixRichContentEditorCommon = require('wix-rich-content-editor-common');
var testkit = require('wix-rich-content-ui-components/testkit');
require('ricos-types');
require('wix-rich-content-plugin-commons');
var ricosSchema = require('ricos-schema');
require('react');
require('lodash');

const ROOT = "imageViewer";
const SETTINGS_IMAGE_PREVIEW = "imagePreview";
const SETTINGS_CAPTION_INPUT = "imageSettingsCaptionInput";
const SETTINGS_ALT_INPUT_TEXT = "imageSettingsAltInput";
const SETTINGS_DISABLE_EXPAND_TOGGLE = "imageSettingsDisableExpandToggle";
const SETTINGS_DISABLE_DOWNLOAD_TOGGLE = "imageSettingsDisableDownloadToggle";
const SETTINGS_SPOILER_TOGGLE = "imageSettingsSpoilerToggle";

Object.freeze({
  containerData: {
    alignment: ricosSchema.PluginContainerData_Alignment.CENTER,
    width: {
      size: ricosSchema.PluginContainerData_Width_Type.CONTENT
    },
    textWrap: true
  }
});
({
  settings: `${ricosSchema.Node_Type.IMAGE}.settings`,
  imageEditor: `${ricosSchema.Node_Type.IMAGE}.imageEditor`
});
({
  size: `${ricosSchema.Node_Type.IMAGE}.size`,
  alignment: `${ricosSchema.Node_Type.IMAGE}.alignment`
});

const imageAddToolbars = [
  wixRichContentEditorCommon.TOOLBARS.MOBILE,
  wixRichContentEditorCommon.TOOLBARS.FOOTER,
  wixRichContentEditorCommon.TOOLBARS.SIDE
];

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
const createImageTestkit = (getBase) => {
  const getImage = async (index, options) => {
    const image = await getBase().getAll(wixRichContentCommon.dataHook(ROOT), options);
    return image.at(index);
  };
  const getImageTag = async () => await getBase().get(`${wixRichContentCommon.dataHook(ROOT)} img`);
  return {
    content: {
      atIndex: (index) => {
        return {
          exists: async (options) => {
            try {
              const image = await getImage(index, options);
              return image.exists();
            } catch (error) {
              return false;
            }
          },
          click: async () => {
            const image = await getImage(index);
            await image.click();
          },
          getText: async () => (await getImage(index)).text(),
          getAlt: async () => (await getImageTag())._prop("alt"),
          hasSpoiler: async () => {
            try {
              const spoiler = await getBase().get(wixRichContentCommon.dataHook("spoilerContainer"));
              return spoiler.exists();
            } catch (error) {
              return false;
            }
          },
          getStyle: async () => (await getImageTag()).attr("style")
        };
      }
    },
    settings: __spreadValues({
      image: unidriver.ImageUniDriver(getBase().$(wixRichContentCommon.dataHook(SETTINGS_IMAGE_PREVIEW)), getBase()),
      disableExpandToggle: unidriver.ToggleSwitchUniDriver(
        getBase().$(wixRichContentCommon.dataHook(SETTINGS_DISABLE_EXPAND_TOGGLE)),
        getBase()
      ),
      disableDownloadToggle: unidriver.ToggleSwitchUniDriver(
        getBase().$(wixRichContentCommon.dataHook(SETTINGS_DISABLE_DOWNLOAD_TOGGLE)),
        getBase()
      ),
      spoilerToggle: unidriver.ToggleSwitchUniDriver(
        getBase().$(wixRichContentCommon.dataHook(SETTINGS_SPOILER_TOGGLE)),
        getBase()
      ),
      captionInput: __spreadValues({
        waitForElement: async () => {
          await getBase().get(wixRichContentCommon.dataHook(SETTINGS_CAPTION_INPUT));
        }
      }, unidriver.InputUniDriver(getBase().$(wixRichContentCommon.dataHook(SETTINGS_CAPTION_INPUT)), getBase())),
      altTextInput: unidriver.InputUniDriver(getBase().$(wixRichContentCommon.dataHook(SETTINGS_ALT_INPUT_TEXT)), getBase())
    }, testkit.createFooterActionsUnidriver(getBase)),
    toolbars: {
      createAddButtonToolbars: (getAddButtonBase) => ({
        click: async () => {
          const imagePluginButton = await getAddButtonBase().get(
            wixRichContentCommon.dataHook(wixRichContentEditorCommon.INSERT_PLUGIN_BUTTONS.IMAGE)
          );
          await imagePluginButton.click();
        },
        toolbarsToAddIn: imageAddToolbars
      }),
      createPluginToolbar: (getPluginToolbarBase) => ({
        openSettingsModal: async () => {
          const settings = await getPluginToolbarBase(wixRichContentCommon.RicosPluginToolbarNames.IMAGE).get(
            wixRichContentCommon.dataHook("baseToolbarButton_settings")
          );
          await settings.click();
        },
        clickDelete: async () => {
          const button = await getPluginToolbarBase(wixRichContentCommon.RicosPluginToolbarNames.IMAGE).get(
            wixRichContentCommon.dataHook("blockButton_delete")
          );
          await button.click();
        },
        openLinkPanel: async () => {
          const button = await getPluginToolbarBase(wixRichContentCommon.RicosPluginToolbarNames.IMAGE).get(
            wixRichContentCommon.dataHook("LinkButton")
          );
          await button.click();
        },
        clickSizeDropdown: async () => {
          const dropdown = await getPluginToolbarBase(wixRichContentCommon.RicosPluginToolbarNames.IMAGE).get(
            wixRichContentCommon.dataHook("nodeSizeButton")
          );
          await dropdown.click();
        },
        imageSize: {
          clickSmall: async () => {
            const allignmentButton = await getBase().get(
              wixRichContentCommon.dataHook("blockAlignmentAndSizeButton_sizeSmallCenter")
            );
            await allignmentButton.click();
          }
        },
        exists: async () => {
          try {
            return getPluginToolbarBase(wixRichContentCommon.RicosPluginToolbarNames.IMAGE).exists();
          } catch (error) {
            return false;
          }
        }
      })
    }
  };
};

exports.createImageTestkit = createImageTestkit;
//# sourceMappingURL=testkit.js.map
