'use strict';

var classNames = require('classnames');
var React = require('react');
var wixRichContentUiComponents = require('wix-rich-content-ui-components');
var imageViewer_rtlignore = require('../image-viewer.rtlignore-f6a3b7a2.js');
var consts = require('../consts.js');
var icons_expand = require('../icons/expand.js');
var viewer_imageContainer = require('./image-container.js');
var viewer_useCustomWidthStyle = require('./use-custom-width-style.js');
var viewer_useFallbackWidthStyle = require('./use-fallback-width-style.js');
var viewer_useImageDimensions = require('./use-image-dimensions.js');
var viewer_useImageSocialAttributes = require('./use-image-social-attributes.js');
require('../style-inject.es-e29c91b9.js');
require('ricos-schema');
require('../dataHooks.js');
require('lodash');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var classNames__default = /*#__PURE__*/_interopDefaultCompat(classNames);
var React__default = /*#__PURE__*/_interopDefaultCompat(React);

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
const Image = ({
  dataUrl,
  node,
  className,
  config,
  helpers,
  isMobile,
  seoMode,
  imageClickActionConfig,
  expand,
  captionComponent,
  shouldLazyLoadImages
}) => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l, _m, _n, _o, _p;
  const containerData = ((_a = node.imageData) == null ? void 0 : _a.containerData) || consts.RICOS_DEFAULTS.containerData;
  const { image, altText } = node.imageData || {};
  const { src } = image || {};
  const disableDownload = ((_b = node.imageData) == null ? void 0 : _b.disableDownload) === true ? (e) => e.preventDefault() : void 0;
  const imageSource = React.useMemo(() => {
    if (dataUrl) {
      return dataUrl;
    }
    const { url, id } = src || {};
    if (url) {
      return url;
    }
    const { getImageUrl } = helpers != null ? helpers : {};
    if (getImageUrl && id) {
      return getImageUrl({ file_name: id });
    }
    return id;
  }, [
    dataUrl,
    (_e = (_d = (_c = node.imageData) == null ? void 0 : _c.image) == null ? void 0 : _d.src) == null ? void 0 : _e.url,
    (_h = (_g = (_f = node.imageData) == null ? void 0 : _f.image) == null ? void 0 : _g.src) == null ? void 0 : _h.id,
    helpers == null ? void 0 : helpers.getImageUrl
  ]);
  const { width, height } = viewer_useImageDimensions.useImageDimensions({
    src: imageSource,
    containerData,
    image
  });
  const fallbackWidthStyle = viewer_useFallbackWidthStyle.useFallbackWidthStyle({ containerData, isMobile });
  const customWidthStyle = viewer_useCustomWidthStyle.useCustomWidthStyle({ containerData, isMobile, width });
  const socialAttributes = viewer_useImageSocialAttributes.useImageSocialAttributes({
    config,
    src,
    width: image == null ? void 0 : image.width,
    height: image == null ? void 0 : image.height
  });
  const doDimensionsExist = width !== void 0 && height !== void 0;
  return /* @__PURE__ */ React__default.default.createElement(viewer_imageContainer.ImageContainer, __spreadProps(__spreadValues({}, imageClickActionConfig), { disableDownload }), doDimensionsExist && imageSource && /* @__PURE__ */ React__default.default.createElement(
    wixRichContentUiComponents.Image,
    __spreadValues({
      id: (_l = (_k = (_j = (_i = node.imageData) == null ? void 0 : _i.image) == null ? void 0 : _j.src) == null ? void 0 : _k.id) != null ? _l : imageSource,
      containerId: node.id,
      displayMode: "fill",
      width,
      height,
      uri: (_p = (_o = (_n = (_m = node.imageData) == null ? void 0 : _m.image) == null ? void 0 : _n.src) == null ? void 0 : _o.id) != null ? _p : imageSource,
      alt: altText || "",
      containerProps: {
        className: classNames__default.default(imageViewer_rtlignore.styles.imageWrapper, imageViewer_rtlignore.styles.imageRatio, className, {
          [imageViewer_rtlignore.styles.pointer]: !!expand
        }),
        containerId: node.id,
        style: __spreadValues(__spreadValues({
          ["--dim-height"]: height,
          ["--dim-width"]: width
        }, fallbackWidthStyle), customWidthStyle)
      },
      imageStyles: {
        maxWidth: "100%"
      },
      socialAttrs: socialAttributes,
      isSEOBot: !!seoMode
    }, shouldLazyLoadImages ? {
      placeholderTransition: seoMode ? void 0 : "blur",
      shouldUseLQIP: (config == null ? void 0 : config.disableTransition) !== false
    } : {})
  ), !!expand && /* @__PURE__ */ React__default.default.createElement(
    "div",
    {
      className: imageViewer_rtlignore.styles.expandContainer,
      onClick: expand,
      onKeyDown: (e) => {
        if (e.key === "Enter" || e.key === " ") {
          expand(e);
        }
      },
      role: "button",
      tabIndex: 0
    },
    /* @__PURE__ */ React__default.default.createElement(icons_expand, { className: imageViewer_rtlignore.styles.expandIcon })
  ), captionComponent);
};

exports.Image = Image;
//# sourceMappingURL=image.js.map
