import { Node_Type } from 'ricos-types';
import { TOOLBARS, INSERT_PLUGIN_BUTTONS } from 'wix-rich-content-editor-common';
import { Uploader } from 'wix-rich-content-plugin-commons';
import { RICOS_DEFAULTS } from './consts.js';
import { ImagePluginService } from './toolbar/imagePluginService.js';
import { IMAGE_TYPE } from './types.js';
import InsertPluginIcon from './icons/InsertPluginIcon.js';
import 'ricos-schema';
import 'lodash';
import 'react';

const imagePluginService = new ImagePluginService();
const handleExternalFileChange = (editorCommands, updateService) => ({ data }) => {
  if (data instanceof Array) {
    data.forEach((file, index) => {
      setTimeout(() => {
        const nodeId = editorCommands.insertBlockWithBlankLines(IMAGE_TYPE, RICOS_DEFAULTS, {
          updateSelection: data.length === index + 1
        });
        updateService.updatePluginData({ data: file }, nodeId, IMAGE_TYPE, imagePluginService);
      });
    });
  } else {
    const nodeId = editorCommands.insertBlockWithBlankLines(IMAGE_TYPE, RICOS_DEFAULTS);
    updateService.updatePluginData({ data }, nodeId, IMAGE_TYPE, imagePluginService);
  }
};
const handleNativeFileChange = (editorCommands, uploadService, uploader) => (files) => {
  files.forEach((file, index) => {
    setTimeout(() => {
      const nodeId = editorCommands.insertBlockWithBlankLines(IMAGE_TYPE, RICOS_DEFAULTS, {
        updateSelection: files.length === index + 1
      });
      uploadService.uploadFile(
        new File([file], file.name, { type: file.type }),
        nodeId,
        uploader,
        IMAGE_TYPE,
        imagePluginService
      );
    });
  });
};
const imageAddToolbars = [
  TOOLBARS.MOBILE,
  TOOLBARS.FOOTER,
  TOOLBARS.SIDE
];
const getAddButtons = (config, services) => {
  return [
    {
      id: Node_Type.IMAGE,
      label: INSERT_PLUGIN_BUTTONS.IMAGE,
      dataHook: INSERT_PLUGIN_BUTTONS.IMAGE,
      icon: InsertPluginIcon,
      tooltip: "ImagePlugin_InsertButton_Tooltip",
      toolbars: imageAddToolbars,
      command: ({ editorCommands }) => {
        const { uploadService, updateService } = services;
        if (config.handleFileSelection) {
          config.handleFileSelection(
            void 0,
            !!config.multi,
            handleExternalFileChange(editorCommands, updateService),
            void 0,
            RICOS_DEFAULTS
          );
        } else {
          const { accept = "image/*", multi = true, handleFileUpload } = config;
          uploadService == null ? void 0 : uploadService.selectFiles(
            accept,
            multi,
            handleNativeFileChange(editorCommands, uploadService, new Uploader(handleFileUpload))
          );
        }
        return true;
      },
      menuConfig: {
        tags: "Image_plugin_search_tags"
      }
    }
  ];
};

export { getAddButtons, imageAddToolbars };
//# sourceMappingURL=getAddButtons.js.map
