import React from 'react';
import { PLUGIN_TOOLBAR_BUTTON_ID, decorateComponentWithProps } from 'wix-rich-content-editor-common';
import { getVisibleOnlyOnDesktopResolver, selectedNodeResolver, Uploader } from 'wix-rich-content-plugin-commons';
import { SizePanel, NodeSizeButton, AlignmentPanel, NodeAlignmentButton } from 'wix-rich-content-toolbars-ui';
import { IMAGE_BUTTONS, imageModals } from './consts.js';
import ImageEditorModal from './image-editor-modal/image-editor-modal.js';
import { Settings } from './settings/settings.js';
import ImageEditorButton from './toolbar/ImageEditorButton.js';
import { ImagePluginService } from './toolbar/imagePluginService.js';
import { IMAGE_TYPE } from './types.js';
import 'ricos-schema';
import 'ricos-context';
import './imageStudio/image-editor-logic.js';
import './imageStudio/image-studio-opener-loader.js';
import '@wix/design-system';
import 'wix-rich-content-ui-components';
import './dataHooks.js';
import './settings/use-spoiler-plugin.js';
import 'ricos-content';
import 'lodash';

const imagePluginService = new ImagePluginService();
const getToolbarButtons = (config, services) => {
  const {
    modals,
    uploadService,
    updateService,
    context: { isMobile }
  } = services;
  return [
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SIZE,
      modal: {
        Component: decorateComponentWithProps(SizePanel, {
          options: [
            "SMALL",
            "CONTENT",
            "FULL_WIDTH",
            "ORIGINAL"
          ]
        }),
        id: IMAGE_BUTTONS.size
      },
      renderer: (toolbarItem) => /* @__PURE__ */ React.createElement(NodeSizeButton, { id: IMAGE_BUTTONS.size, toolbarItem })
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR,
      attributes: {
        visible: getVisibleOnlyOnDesktopResolver(isMobile)
      }
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.ALIGNMENT,
      modal: {
        Component: AlignmentPanel,
        id: IMAGE_BUTTONS.alignment
      },
      renderer: (toolbarItem) => /* @__PURE__ */ React.createElement(NodeAlignmentButton, { toolbarItem, id: IMAGE_BUTTONS.alignment })
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR,
      attributes: {
        visible: getVisibleOnlyOnDesktopResolver(isMobile)
      }
    },
    {
      id: imageModals.imageEditor,
      modal: {
        Component: decorateComponentWithProps(ImageEditorModal, {
          imagePluginService,
          imageEditorWixSettings: config.imageEditorWixSettings,
          onImageEditorOpen: config.onImageEditorOpen
        }),
        id: imageModals.imageEditor
      },
      dataHook: "imageToolbarButton_image_editor",
      command: ({ src, attributes: { selectedNode } }) => {
        modals == null ? void 0 : modals.openModal(imageModals.imageEditor, {
          componentProps: {
            nodeId: selectedNode.attrs.id,
            src,
            handleFileUpload: config.handleFileUpload
          },
          positioning: { placement: "top" },
          layout: "fullscreen"
        });
      },
      renderer: (toolbarItem) => /* @__PURE__ */ React.createElement(ImageEditorButton, { toolbarItem }),
      attributes: {
        visible: getIsEditImageVisibleResolver(config, isMobile),
        selectedNode: selectedNodeResolver
      }
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR,
      attributes: {
        visible: getIsEditImageVisibleResolver(config, isMobile)
      }
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.LINK
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SETTINGS,
      modal: {
        Component: Settings,
        id: imageModals.settings
      },
      command: ({ isMobile: isMobile2, attributes: { selectedNode } }) => {
        modals == null ? void 0 : modals.openModal(imageModals.settings, {
          componentProps: {
            nodeId: selectedNode.attrs.id,
            config
          },
          positioning: { placement: "right" },
          layout: isMobile2 ? "fullscreen" : "drawer"
        });
      }
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.REPLACE,
      tooltip: "ReplaceImageButton_Tooltip",
      command: ({ attributes: { selectedNode } }) => {
        if (config.handleFileSelection) {
          config.handleFileSelection(
            void 0,
            false,
            ({ data }) => {
              const file = Array.isArray(data) ? data[0] : data;
              updateService.updatePluginData(
                { data: file },
                selectedNode.attrs.id,
                IMAGE_TYPE,
                imagePluginService
              );
            },
            void 0,
            {}
          );
        } else {
          const { accept = "image/*", handleFileUpload } = config;
          uploadService.selectFiles(
            accept,
            false,
            (files) => uploadService.uploadFile(
              files[0],
              selectedNode.attrs.id,
              new Uploader(handleFileUpload),
              IMAGE_TYPE,
              imagePluginService
            )
          );
        }
      }
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.SEPARATOR
    },
    {
      id: PLUGIN_TOOLBAR_BUTTON_ID.DELETE
    }
  ];
};
const getIsEditImageVisibleResolver = (config, isMobile) => ({
  id: "IS_IMAGE_EDIT_BUTTON_VISIBLE",
  resolve: () => !!config.imageEditorWixSettings && !isMobile
});

export { getToolbarButtons };
//# sourceMappingURL=getToolbarButtons.js.map
