import { ImageUniDriver, ToggleSwitchUniDriver, InputUniDriver } from '@wix/design-system/dist/testkit/unidriver';
import { dataHook, RicosPluginToolbarNames } from 'wix-rich-content-common';
import { TOOLBARS, INSERT_PLUGIN_BUTTONS } from 'wix-rich-content-editor-common';
import { createFooterActionsUnidriver } from 'wix-rich-content-ui-components/testkit';
import 'ricos-types';
import 'wix-rich-content-plugin-commons';
import { PluginContainerData_Alignment, PluginContainerData_Width_Type, Node_Type } from 'ricos-schema';
import 'react';
import 'lodash';

const ROOT = "imageViewer";
const SETTINGS_IMAGE_PREVIEW = "imagePreview";
const SETTINGS_CAPTION_INPUT = "imageSettingsCaptionInput";
const SETTINGS_ALT_INPUT_TEXT = "imageSettingsAltInput";
const SETTINGS_DISABLE_EXPAND_TOGGLE = "imageSettingsDisableExpandToggle";
const SETTINGS_DISABLE_DOWNLOAD_TOGGLE = "imageSettingsDisableDownloadToggle";
const SETTINGS_SPOILER_TOGGLE = "imageSettingsSpoilerToggle";

Object.freeze({
  containerData: {
    alignment: PluginContainerData_Alignment.CENTER,
    width: {
      size: PluginContainerData_Width_Type.CONTENT
    },
    textWrap: true
  }
});
({
  settings: `${Node_Type.IMAGE}.settings`,
  imageEditor: `${Node_Type.IMAGE}.imageEditor`
});
({
  size: `${Node_Type.IMAGE}.size`,
  alignment: `${Node_Type.IMAGE}.alignment`
});

const imageAddToolbars = [
  TOOLBARS.MOBILE,
  TOOLBARS.FOOTER,
  TOOLBARS.SIDE
];

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
const createImageTestkit = (getBase) => {
  const getImage = async (index, options) => {
    const image = await getBase().getAll(dataHook(ROOT), options);
    return image.at(index);
  };
  const getImageTag = async () => await getBase().get(`${dataHook(ROOT)} img`);
  return {
    content: {
      atIndex: (index) => {
        return {
          exists: async (options) => {
            try {
              const image = await getImage(index, options);
              return image.exists();
            } catch (error) {
              return false;
            }
          },
          click: async () => {
            const image = await getImage(index);
            await image.click();
          },
          getText: async () => (await getImage(index)).text(),
          getAlt: async () => (await getImageTag())._prop("alt"),
          hasSpoiler: async () => {
            try {
              const spoiler = await getBase().get(dataHook("spoilerContainer"));
              return spoiler.exists();
            } catch (error) {
              return false;
            }
          },
          getStyle: async () => (await getImageTag()).attr("style")
        };
      }
    },
    settings: __spreadValues({
      image: ImageUniDriver(getBase().$(dataHook(SETTINGS_IMAGE_PREVIEW)), getBase()),
      disableExpandToggle: ToggleSwitchUniDriver(
        getBase().$(dataHook(SETTINGS_DISABLE_EXPAND_TOGGLE)),
        getBase()
      ),
      disableDownloadToggle: ToggleSwitchUniDriver(
        getBase().$(dataHook(SETTINGS_DISABLE_DOWNLOAD_TOGGLE)),
        getBase()
      ),
      spoilerToggle: ToggleSwitchUniDriver(
        getBase().$(dataHook(SETTINGS_SPOILER_TOGGLE)),
        getBase()
      ),
      captionInput: __spreadValues({
        waitForElement: async () => {
          await getBase().get(dataHook(SETTINGS_CAPTION_INPUT));
        }
      }, InputUniDriver(getBase().$(dataHook(SETTINGS_CAPTION_INPUT)), getBase())),
      altTextInput: InputUniDriver(getBase().$(dataHook(SETTINGS_ALT_INPUT_TEXT)), getBase())
    }, createFooterActionsUnidriver(getBase)),
    toolbars: {
      createAddButtonToolbars: (getAddButtonBase) => ({
        click: async () => {
          const imagePluginButton = await getAddButtonBase().get(
            dataHook(INSERT_PLUGIN_BUTTONS.IMAGE)
          );
          await imagePluginButton.click();
        },
        toolbarsToAddIn: imageAddToolbars
      }),
      createPluginToolbar: (getPluginToolbarBase) => ({
        openSettingsModal: async () => {
          const settings = await getPluginToolbarBase(RicosPluginToolbarNames.IMAGE).get(
            dataHook("baseToolbarButton_settings")
          );
          await settings.click();
        },
        clickDelete: async () => {
          const button = await getPluginToolbarBase(RicosPluginToolbarNames.IMAGE).get(
            dataHook("blockButton_delete")
          );
          await button.click();
        },
        openLinkPanel: async () => {
          const button = await getPluginToolbarBase(RicosPluginToolbarNames.IMAGE).get(
            dataHook("LinkButton")
          );
          await button.click();
        },
        clickSizeDropdown: async () => {
          const dropdown = await getPluginToolbarBase(RicosPluginToolbarNames.IMAGE).get(
            dataHook("nodeSizeButton")
          );
          await dropdown.click();
        },
        imageSize: {
          clickSmall: async () => {
            const allignmentButton = await getBase().get(
              dataHook("blockAlignmentAndSizeButton_sizeSmallCenter")
            );
            await allignmentButton.click();
          }
        },
        exists: async () => {
          try {
            return getPluginToolbarBase(RicosPluginToolbarNames.IMAGE).exists();
          } catch (error) {
            return false;
          }
        }
      })
    }
  };
};

export { createImageTestkit };
//# sourceMappingURL=testkit.js.map
