import React, { useContext } from 'react';
import { RicosViewerContext, RicosContext } from 'ricos-context';
import { IMAGE_TYPE } from '../types.js';
import { alignmentClassName, sizeClassName, textWrapClassName } from './class-name-strategies.js';
import { getExpandFunction } from './get-expand-function.js';
import { getImageClickActionConfig } from './get-image-click-action-config.js';
import { Image } from './image.js';
import { ViewerImageCaption } from './viewer-image-caption.js';
import 'lodash';
import 'ricos-schema';
import '../style-inject.es-e7b07dd7.js';
import 'ricos-content';
import 'classnames';
import 'wix-rich-content-ui-components';
import '../image-viewer.rtlignore-ae1ccfe6.js';
import '../consts.js';
import '../icons/expand.js';
import './image-container.js';
import '../dataHooks.js';
import './use-custom-width-style.js';
import './use-fallback-width-style.js';
import './use-image-dimensions.js';
import './use-image-social-attributes.js';

var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
const ViewerImage = ({ node, nodeIndex, NodeViewContainer }) => {
  var _a, _b;
  const { config: viewerConfig, seoMode, helpers } = useContext(RicosViewerContext);
  const { isMobile, t } = useContext(RicosContext);
  const config = (_a = viewerConfig[IMAGE_TYPE]) != null ? _a : {};
  const expand = getExpandFunction({
    helpers,
    config,
    nodeId: node.id,
    imageData: node.imageData
  });
  const imageClickActionConfig = getImageClickActionConfig({
    imageData: node.imageData,
    config,
    expand
  });
  return /* @__PURE__ */ React.createElement(
    NodeViewContainer,
    {
      node,
      nodeIndex,
      customClassNames: {
        alignment: alignmentClassName(node),
        size: sizeClassName(node, isMobile),
        textWrap: textWrapClassName(node)
      }
    },
    /* @__PURE__ */ React.createElement(
      Image,
      {
        node,
        imageClickActionConfig,
        expand,
        config,
        seoMode,
        helpers,
        isMobile,
        shouldLazyLoadImages: true,
        captionComponent: /* @__PURE__ */ React.createElement(
          ViewerImageCaption,
          {
            imageType: imageClickActionConfig.type,
            caption: (_b = node == null ? void 0 : node.imageData) == null ? void 0 : _b.caption,
            defaultCaption: t("ImageViewer_Caption")
          }
        )
      }
    )
  );
};
const ImageRenderer = (_a) => {
  var _b = _a, { node } = _b, props = __objRest(_b, ["node"]);
  return /* @__PURE__ */ React.createElement(ViewerImage, __spreadValues({ key: node.id, node }, props));
};

export { ImageRenderer as default };
//# sourceMappingURL=viewer-image.js.map
